@@ -100,8 +100,10 @@ use hvcg_iam_openapi_identity::{
     CreateUserResponse,
     DeactivateUserResponse,
     UpdatePasswordResponse,
+    UpdateUserResponse,
     QueryUserByIdResponse,
     QueryUsersResponse,
+    DeleteSaintResponse,
 };
 use hvcg_iam_openapi_identity::server::MakeService;
 use std::error::Error;
@@ -154,6 +156,18 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
         Err("Generic failuare".into())
     }
 
+    /// Update an existing user
+    async fn update_user(
+        &self,
+        id: uuid::Uuid,
+        user: models::User,
+        context: &C) -> Result<UpdateUserResponse, ApiError>
+    {
+        let context = context.clone();
+        info!("update_user({:?}, {:?}) - X-Span-ID: {:?}", id, user, context.get().0.clone());
+        Err("Generic failuare".into())
+    }
+
     /// Get user infomation by id
     async fn query_user_by_id(
         &self,
@@ -181,4 +195,15 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
         Err("Generic failuare".into())
     }
 
+    /// Deletes a saint
+    async fn delete_saint(
+        &self,
+        id: uuid::Uuid,
+        context: &C) -> Result<DeleteSaintResponse, ApiError>
+    {
+        let context = context.clone();
+        info!("delete_saint({:?}) - X-Span-ID: {:?}", id, context.get().0.clone());
+        Err("Generic failuare".into())
+    }
+
 }
