@@ -10,7 +10,7 @@ use serde::{Serialize, Deserialize};
 type ServiceError = Box<dyn Error + Send + Sync + 'static>;
 
 pub const BASE_PATH: &'static str = "";
-pub const API_VERSION: &'static str = "0.0.9";
+pub const API_VERSION: &'static str = "0.1.1";
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
@@ -56,6 +56,23 @@ pub enum UpdatePasswordResponse {
     InvalidInput
 }
 
+#[derive(Debug, PartialEq, Serialize, Deserialize)]
+#[must_use]
+pub enum UpdateUserResponse {
+    /// successful operation
+    SuccessfulOperation
+    (models::User)
+    ,
+    /// Invalid ID supplied
+    InvalidIDSupplied
+    ,
+    /// Saint not found
+    SaintNotFound
+    ,
+    /// Validation exception
+    ValidationException
+}
+
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
 pub enum QueryUserByIdResponse {
@@ -84,6 +101,19 @@ pub enum QueryUsersResponse {
     UserNotFound
 }
 
+#[derive(Debug, PartialEq, Serialize, Deserialize)]
+#[must_use]
+pub enum DeleteSaintResponse {
+    /// successful operation
+    SuccessfulOperation
+    ,
+    /// Invalid ID supplied
+    InvalidIDSupplied
+    ,
+    /// Saint not found
+    SaintNotFound
+}
+
 /// API
 #[async_trait]
 pub trait Api<C: Send + Sync> {
@@ -115,6 +145,13 @@ pub trait Api<C: Send + Sync> {
         inline_object: models::InlineObject,
         context: &C) -> Result<UpdatePasswordResponse, ApiError>;
 
+    /// Update an existing user
+    async fn update_user(
+        &self,
+        id: uuid::Uuid,
+        user: models::User,
+        context: &C) -> Result<UpdateUserResponse, ApiError>;
+
     /// Get user infomation by id
     async fn query_user_by_id(
         &self,
@@ -132,6 +169,12 @@ pub trait Api<C: Send + Sync> {
         count: Option<i32>,
         context: &C) -> Result<QueryUsersResponse, ApiError>;
 
+    /// Deletes a saint
+    async fn delete_saint(
+        &self,
+        id: uuid::Uuid,
+        context: &C) -> Result<DeleteSaintResponse, ApiError>;
+
 }
 
 /// API where `Context` isn't passed on every API call
@@ -166,6 +209,13 @@ pub trait ApiNoContext<C: Send + Sync> {
         inline_object: models::InlineObject,
         ) -> Result<UpdatePasswordResponse, ApiError>;
 
+    /// Update an existing user
+    async fn update_user(
+        &self,
+        id: uuid::Uuid,
+        user: models::User,
+        ) -> Result<UpdateUserResponse, ApiError>;
+
     /// Get user infomation by id
     async fn query_user_by_id(
         &self,
@@ -183,6 +233,12 @@ pub trait ApiNoContext<C: Send + Sync> {
         count: Option<i32>,
         ) -> Result<QueryUsersResponse, ApiError>;
 
+    /// Deletes a saint
+    async fn delete_saint(
+        &self,
+        id: uuid::Uuid,
+        ) -> Result<DeleteSaintResponse, ApiError>;
+
 }
 
 /// Trait to extend an API to make it easy to bind it to a context.
@@ -248,6 +304,17 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
         self.api().update_password(inline_object, &context).await
     }
 
+    /// Update an existing user
+    async fn update_user(
+        &self,
+        id: uuid::Uuid,
+        user: models::User,
+        ) -> Result<UpdateUserResponse, ApiError>
+    {
+        let context = self.context().clone();
+        self.api().update_user(id, user, &context).await
+    }
+
     /// Get user infomation by id
     async fn query_user_by_id(
         &self,
@@ -273,6 +340,16 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
         self.api().query_users(username, phone, email, enabled, offset, count, &context).await
     }
 
+    /// Deletes a saint
+    async fn delete_saint(
+        &self,
+        id: uuid::Uuid,
+        ) -> Result<DeleteSaintResponse, ApiError>
+    {
+        let context = self.context().clone();
+        self.api().delete_saint(id, &context).await
+    }
+
 }
 
 
