@@ -4,6 +4,54 @@ use crate::models;
 #[cfg(any(feature = "client", feature = "server"))]
 use crate::header;
 
+/// The cognito user groups.
+/// Enumeration of values.
+/// Since this enum's variants do not hold data, we can easily define them them as `#[repr(C)]`
+/// which helps with FFI.
+#[allow(non_camel_case_types)]
+#[repr(C)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, serde::Serialize, serde::Deserialize)]
+#[cfg_attr(feature = "conversion", derive(frunk_enum_derive::LabelledGenericEnum))]
+pub enum Group {
+    #[serde(rename = "ADMINGROUP")]
+    ADMINGROUP,
+    #[serde(rename = "OPERATORGROUP")]
+    OPERATORGROUP,
+    #[serde(rename = "PROFESSORGROUP")]
+    PROFESSORGROUP,
+    #[serde(rename = "STUDENTGROUP")]
+    STUDENTGROUP,
+    #[serde(rename = "UNKNOWN")]
+    UNKNOWN,
+}
+
+impl std::fmt::Display for Group {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match *self {
+            Group::ADMINGROUP => write!(f, "{}", "ADMINGROUP"),
+            Group::OPERATORGROUP => write!(f, "{}", "OPERATORGROUP"),
+            Group::PROFESSORGROUP => write!(f, "{}", "PROFESSORGROUP"),
+            Group::STUDENTGROUP => write!(f, "{}", "STUDENTGROUP"),
+            Group::UNKNOWN => write!(f, "{}", "UNKNOWN"),
+        }
+    }
+}
+
+impl std::str::FromStr for Group {
+    type Err = String;
+
+    fn from_str(s: &str) -> std::result::Result<Self, Self::Err> {
+        match s {
+            "ADMINGROUP" => std::result::Result::Ok(Group::ADMINGROUP),
+            "OPERATORGROUP" => std::result::Result::Ok(Group::OPERATORGROUP),
+            "PROFESSORGROUP" => std::result::Result::Ok(Group::PROFESSORGROUP),
+            "STUDENTGROUP" => std::result::Result::Ok(Group::STUDENTGROUP),
+            "UNKNOWN" => std::result::Result::Ok(Group::UNKNOWN),
+            _ => std::result::Result::Err(format!("Value not valid: {}", s)),
+        }
+    }
+}
+
 #[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
 #[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
 pub struct InlineObject {
@@ -370,6 +418,14 @@ pub struct User {
     #[serde(skip_serializing_if="Option::is_none")]
     pub phone: Option<String>,
 
+    #[serde(rename = "enabled")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub enabled: Option<bool>,
+
+    #[serde(rename = "group")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub group: Option<models::Group>,
+
 }
 
 impl User {
@@ -379,6 +435,8 @@ impl User {
             username: username,
             email: None,
             phone: None,
+            enabled: None,
+            group: None,
         }
     }
 }
@@ -407,6 +465,14 @@ impl std::string::ToString for User {
             params.push(phone.to_string());
         }
 
+
+        if let Some(ref enabled) = self.enabled {
+            params.push("enabled".to_string());
+            params.push(enabled.to_string());
+        }
+
+        // Skipping group in query parameter serialization
+
         params.join(",").to_string()
     }
 }
@@ -425,6 +491,8 @@ impl std::str::FromStr for User {
             pub username: Vec<String>,
             pub email: Vec<String>,
             pub phone: Vec<String>,
+            pub enabled: Vec<bool>,
+            pub group: Vec<models::Group>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -445,6 +513,8 @@ impl std::str::FromStr for User {
                     "username" => intermediate_rep.username.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "email" => intermediate_rep.email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "phone" => intermediate_rep.phone.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "enabled" => intermediate_rep.enabled.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "group" => intermediate_rep.group.push(<models::Group as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing User".to_string())
                 }
             }
@@ -459,6 +529,8 @@ impl std::str::FromStr for User {
             username: intermediate_rep.username.into_iter().next().ok_or("username missing in User".to_string())?,
             email: intermediate_rep.email.into_iter().next(),
             phone: intermediate_rep.phone.into_iter().next(),
+            enabled: intermediate_rep.enabled.into_iter().next(),
+            group: intermediate_rep.group.into_iter().next(),
         })
     }
 }
